| gpcr | R Documentation |
This data set was obtained by the bios2mds analysis of the two multiple sequence alignment files provided in /msa. The MSA files were prepared as previously described by Deville et al. (2009) and updated with the July 2009 release of Uniprot (https://www.uniprot.org). They correspond to non-redundant sets of non-olfactory class A G-protein-coupled receptors (GPCRs) from H. sapiens and D. melanogaster (283 and 59 sequences, respectively). The data sets from H. sapiens and D. melanogaster constitute the active and supplementary data sets, respectively.
data(gpcr)
gpcr is a named list of three elements:
a named list containing two distance matrices calculated from the mat.dif function (distances based on difference scores) with default parameters:
a 283 by 283 matrix of difference scores between the 283 aligned sequences of human GPCRs.
a 59 by 283 matrix of difference scores between the aligned sequences of GPCRs from H. sapiens and D. melanogaster (283 and 59 sequences, respectively)..
a named list containing sixteen distance matrices calculated from the mat.dis
function (distances based on dissimilarity scores) for the eight substitution matrices in sub.mat (other parameters by default):
are 283 by 283 matrices of dissimilarity scores between the 283 aligned sequences of human GPCRs.
is calculated with PAM40.
is calculated with PAM80.
is calculated with PAM120.
is calculated with PAM250.
is calculated with BLOSUM30.
is calculated with BLOSUM45.
is calculated with BLOSUM62.
is calculated with BLOSUM80.
is calculated with GONNET.
is calculated with JTT.
is calculated with JTT_TM.
is calculated with PHAT.
are 59 by 283 matrices of dissimilarity scores between the 283 aligned sequences from H. sapiens and D. melanogaster
is calculated with PAM40.
is calculated with PAM80.
is calculated with PAM120.
is calculated with PAM250.
is calculated with BLOSUM30.
is calculated with BLOSUM45.
is calculated with BLOSUM62.
is calculated with BLOSUM80.
is calculated with GONNET.
is calculated with JTT.
is calculated with JTT_TM.
is calculated with PHAT.
a typical example of metric MDS analysis with the mmds function of bios2mds using GPCRs from H. sapiens as active data and GPCRs from D. melanogaster, N. vectensis and C. intestinalis for supplementary data.
metric MDS analysis of active data from H. sapiens.
projection of supplementary data from D. melanogaster onto the human active space.
projection of supplementary data from N. vectensis onto active the human space.
projection of supplementary data from C. intestinalis onto the human active space.
Deville J, Rey J and Chabbert M (2009) An indel in transmembrane helix 2 helps to trace the molecular evolution of class A G-protein-coupled receptors. J Mol Evol 68: 475- 489.
# loading gpcr
data(gpcr)
# displaying the matrix of differences scores between GPCRs sequences
# from H. sapiens
gpcr$dif$sapiens.sapiens
# displaying the matrix of dissimilarity scores between GPCRs sequences
# from H. sapiens
gpcr$dis$sapiens.sapiens$PAM250
# displaying the matrix of dissimilarity scores between GPCRs sequences
# from H. sapiens and D. Melanogaster calculated with the BLOSUM45 matrix
gpcr$dis$melanogaster.sapiens$BLOSUM45
# displaying mmds analysis of the MSA of GPCRs from H. sapiens
# and D. Melanogaster
gpcr$mmds$sapiens.active
gpcr$mmds$melanogaster.project
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.